package com.reactlibrary.DemoLibrary;

import com.facebook.react.BuildConfig;
import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReactContextBaseJavaModule;
import com.facebook.react.bridge.ReactMethod;

/**
 * Created by AND004 on 3/14/2018.
 */

public class DemoModule extends ReactContextBaseJavaModule {

    @Override
    public String getName() {
        return "DemoModuleExample";
    }

    public DemoModule(ReactApplicationContext reactContext) {
        super(reactContext);
    }

    @ReactMethod
    public void getPackageName(Callback successCallback) {
        successCallback.invoke(getReactApplicationContext().getPackageName(), BuildConfig.VERSION_NAME);
    }
}
